summaryrefslogtreecommitdiff
path: root/jstests/dur
diff options
context:
space:
mode:
authorBenety Goh <benety@mongodb.com>2014-10-07 14:21:49 -0400
committerBenety Goh <benety@mongodb.com>2014-10-07 19:49:27 -0400
commitb95adf31a0dd25dd2fcc6a13b841415dbdfdbd9b (patch)
tree7a4e710b832f19ce0482642bb726ab7913fa2541 /jstests/dur
parent49e0c8c825fc54f69cf0eca3215a3abd9a860671 (diff)
downloadmongo-b95adf31a0dd25dd2fcc6a13b841415dbdfdbd9b.tar.gz
SERVER-15547 removed tests that rely on tools --dbpath option
Diffstat (limited to 'jstests/dur')
-rwxr-xr-xjstests/dur/dur1_tool.js13
1 files changed, 7 insertions, 6 deletions
diff --git a/jstests/dur/dur1_tool.js b/jstests/dur/dur1_tool.js
index adee933fdb4..f50c3d123c2 100755
--- a/jstests/dur/dur1_tool.js
+++ b/jstests/dur/dur1_tool.js
@@ -111,13 +111,14 @@ stopMongod(30001, /*signal*/9);
// journal file should be present, and non-empty as we killed hard
// mongorestore with --dbpath and --journal options should do a recovery pass
// empty.bson is an empty file so it won't actually insert anything
-log("use mongorestore to recover");
-runMongoProgram("mongorestore", "--dbpath", path2, "--journal", "-d", "test", "-c", "empty", "jstests/dur/data/empty.bson");
-
-// stopMongod seems to be asynchronous (hmmm) so we sleep here.
-// sleep(5000);
+log("use mongod to recover");
+conn = startMongoProgram('mongod', '--port', 30001, '--dbpath', path2,
+ '--journal', '--smallfiles',
+ '--nohttpinterface', '--noprealloc', '--bind_ip', '127.0.0.1');
+verify();
+stopMongod(30001);
// at this point, after clean shutdown, there should be no journal files
log("check no journal files (after presumably clean shutdown)");
@@ -111,13 +111,14 @@ stopMongod(30001, /*signal*/9);
// journal file should be present, and non-empty as we killed hard
-// mongorestore with --dbpath and --journal options should do a recovery pass
+// mongod with --dbpath and --journal options should do a recovery pass
// empty.bson is an empty file so it won't actually insert anything